@@ -38,6 +38,8 @@
 #define TRACKER_STORE_TRANSACTION_MAX                   4000
 #define TRACKER_STORE_MAX_CONCURRENT_QUERIES               2
 
+#define TRACKER_STORE_N_TURTLE_STATEMENTS                 50
+
 #define TRACKER_STORE_QUERY_WATCHDOG_TIMEOUT 10
 #define TRACKER_STORE_MAX_TASK_TIME          30
 
@@ -53,6 +55,7 @@ typedef struct {
 	GThreadPool *global_pool;
 	GSList	    *running_tasks;
 	guint	     watchdog_id;
+	guint        max_task_time;
 } TrackerStorePrivate;
 
 typedef enum {
@@ -175,7 +178,7 @@ process_turtle_file_part (TrackerTurtleReader *reader, GError **error)
 		}
 
 		i++;
-		if (!new_error && i >= 10) {
+		if (!new_error && i >= TRACKER_STORE_N_TURTLE_STATEMENTS) {
 			tracker_data_commit_transaction (&new_error);
 			if (new_error) {
 				tracker_data_rollback_transaction ();
@@ -303,7 +306,8 @@ watchdog_cb (gpointer user_data)
 		running = running->next;
 		thread = task->data.query.running_thread;
 
-		if (thread && g_timer_elapsed (task->data.query.timer, NULL) > TRACKER_STORE_MAX_TASK_TIME) {
+		if (thread && private->max_task_time &&
+		    g_timer_elapsed (task->data.query.timer, NULL) > private->max_task_time) {
 			tracker_data_manager_interrupt_thread (task->data.query.running_thread);
 		}
 	}
@@ -598,9 +602,16 @@ tracker_store_init (void)
 {
 	TrackerStorePrivate *private;
 	gint i;
+	const char *tmp;
 
 	private = g_new0 (TrackerStorePrivate, 1);
 
+	if ((tmp = g_getenv("TRACKER_STORE_MAX_TASK_TIME")) != NULL) {
+		private->max_task_time = atoi (tmp);
+	} else {
+		private->max_task_time = TRACKER_STORE_MAX_TASK_TIME;
+	}
+
 	for (i = 0; i < TRACKER_STORE_N_PRIORITIES; i++) {
 		private->queues[i] = g_queue_new ();
 	}
